# Contributor License Agreement (CLA)

## Individual Contributor License Agreement

Thank you for your interest in contributing to async-python-cassandra-client ("Project"). This Contributor License Agreement ("Agreement") documents the rights granted by contributors to the Project.

### 1. Definitions

"You" (or "Your") shall mean the copyright owner or legal entity authorized by the copyright owner that is making this Agreement.

"Contribution" shall mean any original work of authorship, including any modifications or additions to an existing work, that is intentionally submitted by You to the Project for inclusion in, or documentation of, any of the products owned or managed by the Project.

### 2. Grant of Copyright License

Subject to the terms and conditions of this Agreement, You hereby grant to the Project and to recipients of software distributed by the Project a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable copyright license to reproduce, prepare derivative works of, publicly display, publicly perform, sublicense, and distribute Your Contributions and such derivative works.

### 3. Grant of Patent License

Subject to the terms and conditions of this Agreement, You hereby grant to the Project and to recipients of software distributed by the Project a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable (except as stated in this section) patent license to make, have made, use, offer to sell, sell, import, and otherwise transfer the Work.

### 4. Representations

You represent that:

- You are legally entitled to grant the above license.
- Each of Your Contributions is Your original creation.
- Your Contribution submissions include complete details of any third-party license or other restriction of which you are personally aware and which are associated with any part of Your Contributions.

### 5. Support

You are not expected to provide support for Your Contributions, except to the extent You desire to provide support. You may provide support for free, for a fee, or not at all. Unless required by applicable law or agreed to in writing, You provide Your Contributions on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND.

### 6. Submission

You agree to notify the Project of any facts or circumstances of which you become aware that would make these representations inaccurate in any respect.

## How to Sign

To sign this CLA, please follow these steps:

1. **Read this agreement carefully**
2. **When submitting a pull request**, include the following statement in your PR description:
   ```
   I have read and agree to the Contributor License Agreement.
   ```
3. **Use the same name and email** in your git commits as you use in your GitHub account

## Corporate Contributor License Agreement

If you are contributing on behalf of your employer, please contact the project maintainers for the Corporate CLA.

## Questions?

If you have any questions about this CLA, please open an issue or contact the project maintainers.

---

*This CLA is adapted from the Apache Software Foundation Individual Contributor License Agreement V2.0*
